@@ -88,12 +88,15 @@ gboolean  gdk_get_use_xshm		(void);
 gchar*	                  gdk_get_display		(void);
 G_CONST_RETURN gchar*	  gdk_get_display_arg_name	(void);
 
-#ifndef GDK_DISABLE_DEPRECATED
+#if !defined (GDK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION)
+/* Used by gtk_input_add_full () */
 gint gdk_input_add_full	  (gint		     source,
 			   GdkInputCondition condition,
 			   GdkInputFunction  function,
 			   gpointer	     data,
 			   GdkDestroyNotify  destroy);
+#endif /* !GDK_DISABLE_DEPRECATED || GTK_COMPILATION */
+#ifndef GDK_DISABLE_DEPRECATED
 gint gdk_input_add	  (gint		     source,
 			   GdkInputCondition condition,
 			   GdkInputFunction  function,
@@ -106,14 +109,14 @@ GdkGrabStatus gdk_pointer_grab       (GdkWindow    *window,
 				      GdkEventMask  event_mask,
 				      GdkWindow    *confine_to,
 				      GdkCursor    *cursor,
-				      guint32       time);
+				      guint32       time_);
 GdkGrabStatus gdk_keyboard_grab      (GdkWindow    *window,
 				      gboolean      owner_events,
-				      guint32       time);
+				      guint32       time_);
 
 #ifndef GDK_MULTIHEAD_SAFE
-void          gdk_pointer_ungrab     (guint32       time);
-void          gdk_keyboard_ungrab    (guint32       time);
+void          gdk_pointer_ungrab     (guint32       time_);
+void          gdk_keyboard_ungrab    (guint32       time_);
 gboolean      gdk_pointer_is_grabbed (void);
 
 gint gdk_screen_width  (void) G_GNUC_CONST;
@@ -146,10 +149,12 @@ GType gdk_rectangle_get_type (void);
 
 /* Conversion functions between wide char and multibyte strings. 
  */
+#ifndef GDK_DISABLE_DEPRECATED
 gchar     *gdk_wcstombs          (const GdkWChar   *src);
 gint       gdk_mbstowcs          (GdkWChar         *dest,
 				  const gchar      *src,
 				  gint              dest_max);
+#endif
 
 /* Miscellaneous */
 #ifndef GDK_MULTIHEAD_SAFE
