@@ -64,26 +64,30 @@ static void gtk_button_box_get_child_property (GtkContainer      *container,
 #define DEFAULT_CHILD_IPAD_X 4
 #define DEFAULT_CHILD_IPAD_Y 0
 
-GtkType
+GType
 gtk_button_box_get_type (void)
 {
-  static GtkType button_box_type = 0;
+  static GType button_box_type = 0;
 
   if (!button_box_type)
     {
-      static const GtkTypeInfo button_box_info =
+      static const GTypeInfo button_box_info =
       {
-	"GtkButtonBox",
-	sizeof (GtkButtonBox),
 	sizeof (GtkButtonBoxClass),
-	(GtkClassInitFunc) gtk_button_box_class_init,
-	(GtkObjectInitFunc) gtk_button_box_init,
-	/* reserved_1 */ NULL,
-        /* reserved_2 */ NULL,
-        (GtkClassInitFunc) NULL,
+	NULL,		/* base_init */
+	NULL,		/* base_finalize */
+	(GClassInitFunc) gtk_button_box_class_init,
+	NULL,		/* class_finalize */
+	NULL,		/* class_data */
+	sizeof (GtkButtonBox),
+	0,               /* n_preallocs */
+	(GInstanceInitFunc) gtk_button_box_init,
+	NULL,		/* value_table */
       };
 
-      button_box_type = gtk_type_unique (gtk_box_get_type (), &button_box_info);
+      button_box_type =
+	g_type_register_static (GTK_TYPE_BOX, "GtkButtonBox",
+				&button_box_info, G_TYPE_FLAG_ABSTRACT);
     }
 
   return button_box_type;
@@ -158,7 +162,7 @@ gtk_button_box_class_init (GtkButtonBoxClass *class)
 					      CHILD_PROP_SECONDARY,
 					      g_param_spec_boolean ("secondary", 
 								    _("Secondary"),
-								    _("If TRUE, the child appears in a secondary group of children, suitable for, e.g., help buttons."),
+								    _("If TRUE, the child appears in a secondary group of children, suitable for, e.g., help buttons"),
 								    FALSE,
 								    G_PARAM_READWRITE));
 }
@@ -235,25 +239,12 @@ gtk_button_box_get_child_property (GtkContainer *container,
 				   GValue       *value,
 				   GParamSpec   *pspec)
 {
-  GList *list;
-  GtkBoxChild *child_info = NULL;
-
-  list = GTK_BOX (container)->children;
-  while (list)
-    {
-      child_info = list->data;
-      if (child_info->widget == child)
-	break;
-
-      list = list->next;
-    }
-
-  g_assert (list != NULL);
-  
   switch (property_id)
     {
     case CHILD_PROP_SECONDARY:
-      g_value_set_boolean (value, child_info->is_secondary);
+      g_value_set_boolean (value, 
+			   gtk_button_box_get_child_secondary (GTK_BUTTON_BOX (container), 
+							       child));
       break;
     default:
       GTK_CONTAINER_WARN_INVALID_CHILD_PROPERTY_ID (container, property_id, pspec);
@@ -334,6 +325,43 @@ gtk_button_box_get_layout (GtkButtonBox *widget)
   return widget->layout_style;
 }
 
+/**
+ * gtk_button_box_get_child_secondary:
+ * @widget: a #GtkButtonBox
+ * @child: a child of @widget 
+ * 
+ * Returns whether @child should appear in a secondary group of children.
+ *
+ * Return value: whether @child should appear in a secondary group of children.
+ *
+ * Since: 2.4
+ **/
+gboolean 
+gtk_button_box_get_child_secondary (GtkButtonBox *widget,
+				    GtkWidget    *child)
+{
+  GList *list;
+  GtkBoxChild *child_info;
+
+  g_return_val_if_fail (GTK_IS_BUTTON_BOX (widget), FALSE);
+  g_return_val_if_fail (GTK_IS_WIDGET (child), FALSE);
+
+  child_info = NULL;
+  list = GTK_BOX (widget)->children;
+  while (list)
+    {
+      child_info = list->data;
+      if (child_info->widget == child)
+	break;
+
+      list = list->next;
+    }
+
+  g_return_val_if_fail (list != NULL, FALSE);
+
+  return child_info->is_secondary;
+}
+
 /**
  * gtk_button_box_set_child_secondary
  * @widget: a #GtkButtonBox
