@@ -24,9 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
 #include <string.h>
-#include "gtkalias.h"
 #include "gtkalignment.h"
 #include "gtkbutton.h"
 #include "gtklabel.h"
@@ -43,7 +41,7 @@
 static const GtkBorder default_default_border = { 1, 1, 1, 1 };
 static const GtkBorder default_default_outside_border = { 0, 0, 0, 0 };
 
-/* Time out before giving up on getting a key release when animating
+/* Time out before giving up on getting a key release when animatng
  * the close button.
  */
 #define ACTIVATE_TIMEOUT 250
@@ -61,25 +59,10 @@ enum {
 enum {
   PROP_0,
   PROP_LABEL,
-  PROP_IMAGE,
   PROP_RELIEF,
   PROP_USE_UNDERLINE,
   PROP_USE_STOCK,
-  PROP_FOCUS_ON_CLICK,
-  PROP_XALIGN,
-  PROP_YALIGN,
-};
-
-#define GTK_BUTTON_GET_PRIVATE(o)       (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_BUTTON, GtkButtonPrivate))
-typedef struct _GtkButtonPrivate GtkButtonPrivate;
-
-struct _GtkButtonPrivate
-{
-  gfloat       xalign;
-  gfloat       yalign;
-  GtkWidget   *image;
-  guint        align_set : 1;
-  guint        image_is_stock : 1;
+  PROP_FOCUS_ON_CLICK
 };
 
 static void gtk_button_class_init     (GtkButtonClass   *klass);
@@ -93,8 +76,6 @@ static void gtk_button_get_property   (GObject         *object,
                                        guint            prop_id,
                                        GValue          *value,
                                        GParamSpec      *pspec);
-static void gtk_button_screen_changed (GtkWidget        *widget,
-				       GdkScreen        *previous_screen);
 static void gtk_button_realize        (GtkWidget        *widget);
 static void gtk_button_unrealize      (GtkWidget        *widget);
 static void gtk_button_map            (GtkWidget        *widget);
@@ -119,21 +100,14 @@ static void gtk_real_button_pressed   (GtkButton        *button);
 static void gtk_real_button_released  (GtkButton        *button);
 static void gtk_real_button_activate  (GtkButton         *button);
 static void gtk_button_update_state   (GtkButton        *button);
-static void gtk_button_add            (GtkContainer   *container,
-			               GtkWidget      *widget);
 static GType gtk_button_child_type    (GtkContainer     *container);
 static void gtk_button_finish_activate (GtkButton *button,
 					gboolean   do_it);
 
-static GObject*	gtk_button_constructor (GType                  type,
-					guint                  n_construct_properties,
-					GObjectConstructParam *construct_params);
-static void gtk_button_construct_child (GtkButton             *button);
-static void gtk_button_state_changed   (GtkWidget             *widget,
-					GtkStateType           previous_state);
-static void gtk_button_grab_notify     (GtkWidget             *widget,
-					gboolean               was_grabbed);
-
+static GObject*	gtk_button_constructor     (GType                  type,
+					    guint                  n_construct_properties,
+					    GObjectConstructParam *construct_params);
+static void     gtk_button_construct_child (GtkButton             *button);
 
 
 static GtkBinClass *parent_class = NULL;
@@ -188,7 +162,6 @@ gtk_button_class_init (GtkButtonClass *klass)
 
   object_class->destroy = gtk_button_destroy;
 
-  widget_class->screen_changed = gtk_button_screen_changed;
   widget_class->realize = gtk_button_realize;
   widget_class->unrealize = gtk_button_unrealize;
   widget_class->map = gtk_button_map;
@@ -201,11 +174,8 @@ gtk_button_class_init (GtkButtonClass *klass)
   widget_class->key_release_event = gtk_button_key_release;
   widget_class->enter_notify_event = gtk_button_enter_notify;
   widget_class->leave_notify_event = gtk_button_leave_notify;
-  widget_class->state_changed = gtk_button_state_changed;
-  widget_class->grab_notify = gtk_button_grab_notify;
 
   container_class->child_type = gtk_button_child_type;
-  container_class->add = gtk_button_add;
 
   klass->pressed = gtk_real_button_pressed;
   klass->released = gtk_real_button_released;
@@ -217,96 +187,43 @@ gtk_button_class_init (GtkButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_LABEL,
                                    g_param_spec_string ("label",
-                                                        P_("Label"),
-                                                        P_("Text of the label widget inside the button, if the button contains a label widget"),
+                                                        _("Label"),
+                                                        _("Text of the label widget inside the button, if the button contains a label widget"),
                                                         NULL,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   
   g_object_class_install_property (gobject_class,
                                    PROP_USE_UNDERLINE,
                                    g_param_spec_boolean ("use_underline",
-							 P_("Use underline"),
-							 P_("If set, an underline in the text indicates the next character should be used for the mnemonic accelerator key"),
+							 _("Use underline"),
+							 _("If set, an underline in the text indicates the next character should be used for the mnemonic accelerator key"),
                                                         FALSE,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   
   g_object_class_install_property (gobject_class,
                                    PROP_USE_STOCK,
                                    g_param_spec_boolean ("use_stock",
-							 P_("Use stock"),
-							 P_("If set, the label is used to pick a stock item instead of being displayed"),
+							 _("Use stock"),
+							 _("If set, the label is used to pick a stock item instead of being displayed"),
                                                         FALSE,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   
   g_object_class_install_property (gobject_class,
                                    PROP_FOCUS_ON_CLICK,
                                    g_param_spec_boolean ("focus_on_click",
-							 P_("Focus on click"),
-							 P_("Whether the button grabs focus when it is clicked with the mouse"),
+							 _("Focus on click"),
+							 _("Whether the button grabs focus when it is clicked with the mouse"),
 							 TRUE,
 							 G_PARAM_READWRITE));
   
   g_object_class_install_property (gobject_class,
                                    PROP_RELIEF,
                                    g_param_spec_enum ("relief",
-                                                      P_("Border relief"),
-                                                      P_("The border relief style"),
+                                                      _("Border relief"),
+                                                      _("The border relief style"),
                                                       GTK_TYPE_RELIEF_STYLE,
                                                       GTK_RELIEF_NORMAL,
                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
-  
-  /**
-   * GtkButton:xalign:
-   *
-   * If the child of the button is a #GtkMisc or #GtkAlignment, this property 
-   * can be used to control it's horizontal alignment. 0.0 is left aligned, 
-   * 1.0 is right aligned.
-   * 
-   * Since: 2.4
-   */
-  g_object_class_install_property (gobject_class,
-                                   PROP_XALIGN,
-                                   g_param_spec_float("xalign",
-                                                      P_("Horizontal alignment for child"),
-                                                      P_("Horizontal position of child in available space. 0.0 is left aligned, 1.0 is right aligned"),
-                                                      0.0,
-                                                      1.0,
-                                                      0.5,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
-
-  /**
-   * GtkButton:yalign:
-   *
-   * If the child of the button is a #GtkMisc or #GtkAlignment, this property 
-   * can be used to control it's vertical alignment. 0.0 is top aligned, 
-   * 1.0 is bottom aligned.
-   * 
-   * Since: 2.4
-   */
-  g_object_class_install_property (gobject_class,
-                                   PROP_YALIGN,
-                                   g_param_spec_float("yalign",
-                                                      P_("Vertical alignment for child"),
-                                                      P_("Vertical position of child in available space. 0.0 is top aligned, 1.0 is bottom aligned"),
-                                                      0.0,
-                                                      1.0,
-                                                      0.5,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
-
-  /**
-   * GtkButton::image:
-   * 
-   * The child widget to appear next to the button text.
-   * 
-   * Since: 2.6
-   */
-  g_object_class_install_property (gobject_class,
-                                   PROP_IMAGE,
-                                   g_param_spec_object ("image",
-                                                        P_("Image widget"),
-                                                        P_("Child widget to appear next to the button text"),
-                                                        GTK_TYPE_WIDGET,
-                                                        G_PARAM_READABLE | G_PARAM_WRITABLE));
 
   button_signals[PRESSED] =
     g_signal_new ("pressed",
@@ -348,16 +265,6 @@ gtk_button_class_init (GtkButtonClass *klass)
 		  NULL, NULL,
 		  _gtk_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  /**
-   * GtkButton::activate:
-   * @widget: the object which received the signal.
-   *
-   * The "activate" signal on GtkButton is an action signal and
-   * emitting it causes the button to animate press then release. 
-   * Applications should never connect to this signal, but use the
-   * "clicked" signal.
-   */
   button_signals[ACTIVATE] =
     g_signal_new ("activate",
 		  G_OBJECT_CLASS_TYPE (object_class),
@@ -370,63 +277,38 @@ gtk_button_class_init (GtkButtonClass *klass)
 
   gtk_widget_class_install_style_property (widget_class,
 					   g_param_spec_boxed ("default_border",
-							       P_("Default Spacing"),
-							       P_("Extra space to add for CAN_DEFAULT buttons"),
+							       _("Default Spacing"),
+							       _("Extra space to add for CAN_DEFAULT buttons"),
 							       GTK_TYPE_BORDER,
 							       G_PARAM_READABLE));
 
   gtk_widget_class_install_style_property (widget_class,
 					   g_param_spec_boxed ("default_outside_border",
-							       P_("Default Outside Spacing"),
-							       P_("Extra space to add for CAN_DEFAULT buttons that is always drawn outside the border"),
+							       _("Default Outside Spacing"),
+							       _("Extra space to add for CAN_DEFAULT buttons that is always drawn outside the border"),
 							       GTK_TYPE_BORDER,
 							       G_PARAM_READABLE));
   gtk_widget_class_install_style_property (widget_class,
 					   g_param_spec_int ("child_displacement_x",
-							     P_("Child X Displacement"),
-							     P_("How far in the x direction to move the child when the button is depressed"),
+							     _("Child X Displacement"),
+							     _("How far in the x direction to move the child when the button is depressed"),
 							     G_MININT,
 							     G_MAXINT,
 							     0,
 							     G_PARAM_READABLE));
   gtk_widget_class_install_style_property (widget_class,
 					   g_param_spec_int ("child_displacement_y",
-							     P_("Child Y Displacement"),
-							     P_("How far in the y direction to move the child when the button is depressed"),
+							     _("Child Y Displacement"),
+							     _("How far in the y direction to move the child when the button is depressed"),
 							     G_MININT,
 							     G_MAXINT,
 							     0,
 							     G_PARAM_READABLE));
-
-  /**
-   * GtkButton:displace-focus:
-   *
-   * Whether the child_displacement_x/child_displacement_y properties should also 
-   * affect the focus rectangle.
-   *
-   * Since: 2.6
-   */
-  gtk_widget_class_install_style_property (widget_class,
-					   g_param_spec_boolean ("displace-focus",
-								 P_("Displace focus"),
-								 P_("Whether the child_displacement_x/_y properties should also affect the focus rectangle"),
-						       FALSE,
-						       G_PARAM_READABLE));
-
-  gtk_settings_install_property (g_param_spec_boolean ("gtk-button-images",
-						       P_("Show button images"),
-						       P_("Whether stock icons should be shown in buttons"),
-						       TRUE,
-						       G_PARAM_READWRITE));
-  
-  g_type_class_add_private (gobject_class, sizeof (GtkButtonPrivate));  
 }
 
 static void
 gtk_button_init (GtkButton *button)
 {
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
-
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_FOCUS | GTK_RECEIVES_DEFAULT);
   GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
 
@@ -441,11 +323,6 @@ gtk_button_init (GtkButton *button)
   button->depressed = FALSE;
   button->depress_on_activate = TRUE;
   button->focus_on_click = TRUE;
-
-  priv->xalign = 0.5;
-  priv->yalign = 0.5;
-  priv->align_set = 0;
-  priv->image_is_stock = TRUE;
 }
 
 static void
@@ -493,55 +370,21 @@ gtk_button_child_type  (GtkContainer     *container)
     return G_TYPE_NONE;
 }
 
-static void
-maybe_set_alignment (GtkButton *button,
-		     GtkWidget *widget)
-{
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
-
-  if (GTK_IS_MISC (widget))
-    {
-      GtkMisc *misc = GTK_MISC (widget);
-      
-      if (priv->align_set)
-	gtk_misc_set_alignment (misc, priv->xalign, priv->yalign);
-    }
-  else if (GTK_IS_ALIGNMENT (widget))
-    {
-      GtkAlignment *alignment = GTK_ALIGNMENT (widget);
-
-      if (priv->align_set)
-	gtk_alignment_set (alignment, priv->xalign, priv->yalign, 
-			   alignment->xscale, alignment->yscale);
-    }
-}
-
-static void
-gtk_button_add (GtkContainer *container,
-		GtkWidget    *widget)
-{
-  maybe_set_alignment (GTK_BUTTON (container), widget);
-
-  GTK_CONTAINER_CLASS (parent_class)->add (container, widget);
-}
-
 static void
 gtk_button_set_property (GObject         *object,
                          guint            prop_id,
                          const GValue    *value,
                          GParamSpec      *pspec)
 {
-  GtkButton *button = GTK_BUTTON (object);
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
+  GtkButton *button;
+
+  button = GTK_BUTTON (object);
 
   switch (prop_id)
     {
     case PROP_LABEL:
       gtk_button_set_label (button, g_value_get_string (value));
       break;
-    case PROP_IMAGE:
-      gtk_button_set_image (button, (GtkWidget *) g_value_get_object (value));
-      break;
     case PROP_RELIEF:
       gtk_button_set_relief (button, g_value_get_enum (value));
       break;
@@ -554,12 +397,6 @@ gtk_button_set_property (GObject         *object,
     case PROP_FOCUS_ON_CLICK:
       gtk_button_set_focus_on_click (button, g_value_get_boolean (value));
       break;
-    case PROP_XALIGN:
-      gtk_button_set_alignment (button, g_value_get_float (value), priv->yalign);
-      break;
-    case PROP_YALIGN:
-      gtk_button_set_alignment (button, priv->xalign, g_value_get_float (value));
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -572,17 +409,15 @@ gtk_button_get_property (GObject         *object,
                          GValue          *value,
                          GParamSpec      *pspec)
 {
-  GtkButton *button = GTK_BUTTON (object);
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
+  GtkButton *button;
+
+  button = GTK_BUTTON (object);
 
   switch (prop_id)
     {
     case PROP_LABEL:
       g_value_set_string (value, button->label_text);
       break;
-    case PROP_IMAGE:
-      g_value_set_object (value, (GObject *)priv->image);
-      break;
     case PROP_RELIEF:
       g_value_set_enum (value, gtk_button_get_relief (button));
       break;
@@ -595,12 +430,6 @@ gtk_button_get_property (GObject         *object,
     case PROP_FOCUS_ON_CLICK:
       g_value_set_boolean (value, button->focus_on_click);
       break;
-    case PROP_XALIGN:
-      g_value_set_float (value, priv->xalign);
-      break;
-    case PROP_YALIGN:
-      g_value_set_float (value, priv->yalign);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -613,28 +442,15 @@ gtk_button_new (void)
   return g_object_new (GTK_TYPE_BUTTON, NULL);
 }
 
-static gboolean
-show_image (GtkButton *button)
-{
-  GtkSettings *settings = gtk_widget_get_settings (GTK_WIDGET (button));  
-  gboolean show;
-
-  g_object_get (settings, "gtk-button-images", &show, NULL);
-
-  return show;
-}
-
 static void
 gtk_button_construct_child (GtkButton *button)
 {
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
   GtkStockItem item;
   GtkWidget *label;
+  GtkWidget *image;
   GtkWidget *hbox;
   GtkWidget *align;
-  GtkWidget *image = NULL;
-  gchar *label_text = NULL;
-  
+
   if (!button->constructed)
     return;
   
@@ -642,58 +458,33 @@ gtk_button_construct_child (GtkButton *button)
     return;
 
   if (GTK_BIN (button)->child)
-    {
-      if (priv->image && !priv->image_is_stock)
-	image = g_object_ref (priv->image);
+    gtk_container_remove (GTK_CONTAINER (button),
+			  GTK_BIN (button)->child);
 
-      gtk_container_remove (GTK_CONTAINER (button),
-  			    GTK_BIN (button)->child);
-  
-      priv->image = NULL;
-    }
   
   if (button->use_stock &&
       gtk_stock_lookup (button->label_text, &item))
     {
-      if (!image)
-	image = g_object_ref (gtk_image_new_from_stock (button->label_text, GTK_ICON_SIZE_BUTTON));
+      label = gtk_label_new_with_mnemonic (item.label);
 
-      label_text = item.label;
-    }
-  else
-    label_text = button->label_text;
-
-  if (image)
-    {
-      label = gtk_label_new_with_mnemonic (label_text);
       gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
       
-      priv->image = image;
-
-      g_object_set (priv->image, 
-		    "visible", show_image (button),
-		    "no_show_all", TRUE,
-		    NULL);
+      image = gtk_image_new_from_stock (button->label_text, GTK_ICON_SIZE_BUTTON);
       hbox = gtk_hbox_new (FALSE, 2);
 
-      if (priv->align_set)
-	align = gtk_alignment_new (priv->xalign, priv->yalign, 0.0, 0.0);
-      else
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	
-      gtk_box_pack_start (GTK_BOX (hbox), priv->image, FALSE, FALSE, 0);
+      align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+      
+      gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
       gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
       
       gtk_container_add (GTK_CONTAINER (button), align);
       gtk_container_add (GTK_CONTAINER (align), hbox);
       gtk_widget_show_all (align);
 
-      g_object_unref (image);
-
       return;
     }
-  
- if (button->use_underline)
+
+  if (button->use_underline)
     {
       label = gtk_label_new_with_mnemonic (button->label_text);
       gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
@@ -701,8 +492,7 @@ gtk_button_construct_child (GtkButton *button)
   else
     label = gtk_label_new (button->label_text);
   
-  if (priv->align_set)
-    gtk_misc_set_alignment (GTK_MISC (label), priv->xalign, priv->yalign);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
 
   gtk_widget_show (label);
   gtk_container_add (GTK_CONTAINER (button), label);
@@ -762,7 +552,6 @@ gtk_button_pressed (GtkButton *button)
 {
   g_return_if_fail (GTK_IS_BUTTON (button));
 
-  
   g_signal_emit (button, button_signals[PRESSED], 0);
 }
 
@@ -815,6 +604,7 @@ gtk_button_set_relief (GtkButton *button,
 GtkReliefStyle
 gtk_button_get_relief (GtkButton *button)
 {
+  g_return_val_if_fail (button != NULL, GTK_RELIEF_NORMAL);
   g_return_val_if_fail (GTK_IS_BUTTON (button), GTK_RELIEF_NORMAL);
 
   return button->relief;
@@ -880,6 +670,8 @@ gtk_button_map (GtkWidget *widget)
 {
   GtkButton *button = GTK_BUTTON (widget);
   
+  g_return_if_fail (GTK_IS_BUTTON (widget));
+
   GTK_WIDGET_CLASS (parent_class)->map (widget);
 
   if (button->event_window)
@@ -891,6 +683,8 @@ gtk_button_unmap (GtkWidget *widget)
 {
   GtkButton *button = GTK_BUTTON (widget);
     
+  g_return_if_fail (GTK_IS_BUTTON (widget));
+
   if (button->event_window)
     gdk_window_hide (button->event_window);
 
@@ -942,10 +736,11 @@ gtk_button_size_request (GtkWidget      *widget,
 {
   GtkButton *button = GTK_BUTTON (widget);
   GtkBorder default_border;
+  gboolean interior_focus;
   gint focus_width;
   gint focus_pad;
 
-  gtk_button_get_props (button, &default_border, NULL, NULL);
+  gtk_button_get_props (button, &default_border, NULL, &interior_focus);
   gtk_widget_style_get (GTK_WIDGET (widget),
 			"focus-line-width", &focus_width,
 			"focus-padding", &focus_pad,
@@ -987,15 +782,8 @@ gtk_button_size_allocate (GtkWidget     *widget,
   gint xthickness = GTK_WIDGET (widget)->style->xthickness;
   gint ythickness = GTK_WIDGET (widget)->style->ythickness;
   GtkBorder default_border;
-  gint focus_width;
-  gint focus_pad;
 
   gtk_button_get_props (button, &default_border, NULL, NULL);
-  gtk_widget_style_get (GTK_WIDGET (widget),
-			"focus-line-width", &focus_width,
-			"focus-padding", &focus_pad,
-			NULL);
- 
 			    
   widget->allocation = *allocation;
 
@@ -1024,14 +812,6 @@ gtk_button_size_allocate (GtkWidget     *widget,
 	  child_allocation.height = MAX (1, child_allocation.height - default_border.top - default_border.bottom);
 	}
 
-      if (GTK_WIDGET_CAN_FOCUS (button))
-	{
-	  child_allocation.x += focus_width + focus_pad;
-	  child_allocation.y += focus_width + focus_pad;
-	  child_allocation.width =  MAX (1, child_allocation.width - (focus_width + focus_pad) * 2);
-	  child_allocation.height = MAX (1, child_allocation.height - (focus_width + focus_pad) * 2);
-	}
-
       if (button->depressed)
 	{
 	  gint child_displacement_x;
@@ -1112,8 +892,9 @@ _gtk_button_paint (GtkButton    *button,
 	  height -= 2 * (focus_width + focus_pad);
 	}
 
-      if (button->relief != GTK_RELIEF_NONE || button->depressed ||
-	  GTK_WIDGET_STATE(widget) == GTK_STATE_PRELIGHT)
+      if ((button->relief != GTK_RELIEF_NONE) ||
+	  ((GTK_WIDGET_STATE(widget) != GTK_STATE_NORMAL) &&
+	   (GTK_WIDGET_STATE(widget) != GTK_STATE_INSENSITIVE)))
 	gtk_paint_box (widget->style, widget->window,
 		       state_type,
 		       shadow_type, area, widget, "button",
@@ -1121,22 +902,12 @@ _gtk_button_paint (GtkButton    *button,
        
       if (GTK_WIDGET_HAS_FOCUS (widget))
 	{
-	  gint child_displacement_x;
-	  gint child_displacement_y;
-	  gboolean displace_focus;
-	  
-	  gtk_widget_style_get (GTK_WIDGET (widget),
-				"child_displacement_y", &child_displacement_y,
-				"child_displacement_x", &child_displacement_x,
-				"displace_focus", &displace_focus,
-				NULL);
-
 	  if (interior_focus)
 	    {
 	      x += widget->style->xthickness + focus_pad;
 	      y += widget->style->ythickness + focus_pad;
 	      width -= 2 * (widget->style->xthickness + focus_pad);
-	      height -=  2 * (widget->style->ythickness + focus_pad);
+	      height -=  2 * (widget->style->xthickness + focus_pad);
 	    }
 	  else
 	    {
@@ -1146,12 +917,6 @@ _gtk_button_paint (GtkButton    *button,
 	      height += 2 * (focus_width + focus_pad);
 	    }
 
-	  if (button->depressed && displace_focus)
-	    {
-	      x += child_displacement_x;
-	      y += child_displacement_y;
-	    }
-
 	  gtk_paint_focus (widget->style, widget->window, GTK_WIDGET_STATE (widget),
 			   area, widget, "button",
 			   x, y, width, height);
@@ -1368,13 +1133,10 @@ void
 gtk_button_set_label (GtkButton   *button,
 		      const gchar *label)
 {
-  gchar *new_label;
-  
   g_return_if_fail (GTK_IS_BUTTON (button));
-
-  new_label = g_strdup (label);
+  
   g_free (button->label_text);
-  button->label_text = new_label;
+  button->label_text = g_strdup (label);
   
   gtk_button_construct_child (button);
   
@@ -1493,7 +1255,7 @@ gtk_button_get_use_stock (GtkButton *button)
 /**
  * gtk_button_set_focus_on_click:
  * @button: a #GtkButton
- * @focus_on_click: whether the button grabs focus when clicked with the mouse
+ * @focus_on_click: whether the mouse grabs focus when clicked with the mouse
  * 
  * Sets whether the button will grab focus when it is clicked with the mouse.
  * Making mouse clicks not grab focus is useful in places like toolbars where
@@ -1538,70 +1300,6 @@ gtk_button_get_focus_on_click (GtkButton *button)
   return button->focus_on_click;
 }
 
-/**
- * gtk_button_set_alignment:
- * @button: a #GtkButton
- * @xalign: the horizontal position of the child, 0.0 is left aligned, 
- *   1.0 is right aligned
- * @yalign: the vertical position of the child, 0.0 is top aligned, 
- *   1.0 is bottom aligned
- *
- * Sets the alignment of the child. This property has no effect unless 
- * the child is a #GtkMisc or a #GtkAligment.
- *
- * Since: 2.4
- */
-void
-gtk_button_set_alignment (GtkButton *button,
-			  gfloat     xalign,
-			  gfloat     yalign)
-{
-  GtkButtonPrivate *priv;
-
-  g_return_if_fail (GTK_IS_BUTTON (button));
-  
-  priv = GTK_BUTTON_GET_PRIVATE (button);
-
-  priv->xalign = xalign;
-  priv->yalign = yalign;
-  priv->align_set = 1;
-
-  maybe_set_alignment (button, GTK_BIN (button)->child);
-
-  g_object_freeze_notify (G_OBJECT (button));
-  g_object_notify (G_OBJECT (button), "xalign");
-  g_object_notify (G_OBJECT (button), "yalign");
-  g_object_thaw_notify (G_OBJECT (button));
-}
-
-/**
- * gtk_button_get_alignment:
- * @button: a #GtkButton
- * @xalign: return location for horizontal alignment
- * @yalign: return location for vertical alignment
- *
- * Gets the alignment of the child in the button.
- *
- * Since: 2.4
- */
-void
-gtk_button_get_alignment (GtkButton *button,
-			  gfloat    *xalign,
-			  gfloat    *yalign)
-{
-  GtkButtonPrivate *priv;
-
-  g_return_if_fail (GTK_IS_BUTTON (button));
-  
-  priv = GTK_BUTTON_GET_PRIVATE (button);
- 
-  if (xalign) 
-    *xalign = priv->xalign;
-
-  if (yalign)
-    *yalign = priv->yalign;
-}
-
 /**
  * _gtk_button_set_depressed:
  * @button: a #GtkButton
@@ -1645,146 +1343,3 @@ gtk_button_update_state (GtkButton *button)
   _gtk_button_set_depressed (button, depressed); 
   gtk_widget_set_state (GTK_WIDGET (button), new_state);
 }
-
-static void 
-show_image_change_notify (GtkButton *button)
-{
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
-
-  if (priv->image) 
-    {
-      if (show_image (button))
-	gtk_widget_show (priv->image);
-      else
-	gtk_widget_hide (priv->image);
-    }
-}
-
-static void
-traverse_container (GtkWidget *widget,
-		    gpointer   data)
-{
-  if (GTK_IS_BUTTON (widget))
-    show_image_change_notify (GTK_BUTTON (widget));
-  else if (GTK_IS_CONTAINER (widget))
-    gtk_container_forall (GTK_CONTAINER (widget), traverse_container, NULL);
-}
-
-static void
-gtk_button_setting_changed (GtkSettings *settings)
-{
-  GList *list, *l;
-
-  list = gtk_window_list_toplevels ();
-
-  for (l = list; l; l = l->next)
-    gtk_container_forall (GTK_CONTAINER (l->data), 
-			  traverse_container, NULL);
-
-  g_list_free (list);
-}
-
-
-static void
-gtk_button_screen_changed (GtkWidget *widget,
-			   GdkScreen *previous_screen)
-{
-  GtkSettings *settings;
-  guint show_image_connection;
-
-  if (!gtk_widget_has_screen (widget))
-    return;
-
-  settings = gtk_widget_get_settings (widget);
-
-  show_image_connection = 
-    GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (settings), 
-					 "gtk-button-connection"));
-  
-  if (show_image_connection)
-    return;
-
-  show_image_connection =
-    g_signal_connect (settings, "notify::gtk-button-images",
-		      G_CALLBACK (gtk_button_setting_changed), 0);
-  g_object_set_data (G_OBJECT (settings), 
-		     "gtk-button-connection",
-		     GUINT_TO_POINTER (show_image_connection));
-
-  show_image_change_notify (GTK_BUTTON (widget));
-}
-
-static void
-gtk_button_state_changed (GtkWidget    *widget,
-                          GtkStateType  previous_state)
-{
-  GtkButton *button = GTK_BUTTON (widget);
-
-  if (!GTK_WIDGET_IS_SENSITIVE (widget))
-    {
-      button->in_button = FALSE;
-      gtk_real_button_released (button);
-    }
-}
-
-static void
-gtk_button_grab_notify (GtkWidget *widget,
-			gboolean   was_grabbed)
-{
-  GtkButton *button = GTK_BUTTON (widget);
-
-  if (!was_grabbed)
-    {
-      button->in_button = FALSE;
-      gtk_real_button_released (button);
-    }
-}
-
-/**
- * gtk_button_set_image:
- * @button: a #GtkButton
- * @image: a widget to set as the image for the button
- *
- * Set the image of @button to the given widget. Note that
- * it depends on the gtk-button-images setting whether the
- * image will be displayed or not.
- *
- * Since: 2.6
- */ 
-void
-gtk_button_set_image (GtkButton *button,
-		      GtkWidget *image)
-{
-  GtkButtonPrivate *priv = GTK_BUTTON_GET_PRIVATE (button);
-
-  priv->image = image;
-  priv->image_is_stock = (image == NULL);
-
-  gtk_button_construct_child (button);
-
-  g_object_notify (G_OBJECT (button), "image");
-}
-
-/**
- * gtk_button_get_image:
- * @button: a #GtkButton
- *
- * Gets the widget that is currenty set as the image of @button.
- * This may have been explicitly set by gtk_button_set_image()
- * or constructed by gtk_button_new_from_stock().
- *
- * Since: 2.6
- */
-GtkWidget *
-gtk_button_get_image (GtkButton *button)
-{
-  GtkButtonPrivate *priv;
-
-  g_return_val_if_fail (GTK_IS_BUTTON (button), NULL);
-
-  priv = GTK_BUTTON_GET_PRIVATE (button);
-  
-  return priv->image;
-}
-  
-  
