@@ -38,11 +38,11 @@ extern "C" {
 #endif /* __cplusplus */
 
 #define GTK_TYPE_BUTTON                 (gtk_button_get_type ())
-#define GTK_BUTTON(obj)                 (GTK_CHECK_CAST ((obj), GTK_TYPE_BUTTON, GtkButton))
-#define GTK_BUTTON_CLASS(klass)         (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_BUTTON, GtkButtonClass))
-#define GTK_IS_BUTTON(obj)              (GTK_CHECK_TYPE ((obj), GTK_TYPE_BUTTON))
-#define GTK_IS_BUTTON_CLASS(klass)      (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_BUTTON))
-#define GTK_BUTTON_GET_CLASS(obj)       (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_BUTTON, GtkButtonClass))
+#define GTK_BUTTON(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_BUTTON, GtkButton))
+#define GTK_BUTTON_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_BUTTON, GtkButtonClass))
+#define GTK_IS_BUTTON(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_BUTTON))
+#define GTK_IS_BUTTON_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_BUTTON))
+#define GTK_BUTTON_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_BUTTON, GtkButtonClass))
 
 
 typedef struct _GtkButton       GtkButton;
@@ -66,6 +66,7 @@ struct _GtkButton
   guint use_stock : 1;
   guint depressed : 1;
   guint depress_on_activate : 1;
+  guint focus_on_click : 1;
 };
 
 struct _GtkButtonClass
@@ -87,7 +88,7 @@ struct _GtkButtonClass
 };
 
 
-GtkType        gtk_button_get_type          (void) G_GNUC_CONST;
+GType          gtk_button_get_type          (void) G_GNUC_CONST;
 GtkWidget*     gtk_button_new               (void);
 GtkWidget*     gtk_button_new_with_label    (const gchar    *label);
 GtkWidget*     gtk_button_new_from_stock    (const gchar    *stock_id);
@@ -97,28 +98,32 @@ void           gtk_button_released          (GtkButton      *button);
 void           gtk_button_clicked           (GtkButton      *button);
 void           gtk_button_enter             (GtkButton      *button);
 void           gtk_button_leave             (GtkButton      *button);
-void           gtk_button_set_relief        (GtkButton      *button,
-					     GtkReliefStyle  newstyle);
-GtkReliefStyle gtk_button_get_relief        (GtkButton      *button);
 
-void                  gtk_button_set_label         (GtkButton   *button,
-						    const gchar *label);
-G_CONST_RETURN gchar *gtk_button_get_label         (GtkButton   *button);
-void                  gtk_button_set_use_underline (GtkButton   *button,
-						    gboolean     use_underline);
-gboolean              gtk_button_get_use_underline (GtkButton   *button);
-void                  gtk_button_set_use_stock     (GtkButton   *button,
-						    gboolean     use_stock);
-gboolean              gtk_button_get_use_stock     (GtkButton   *button);
+void                  gtk_button_set_relief         (GtkButton      *button,
+						     GtkReliefStyle  newstyle);
+GtkReliefStyle        gtk_button_get_relief         (GtkButton      *button);
+void                  gtk_button_set_label          (GtkButton      *button,
+						     const gchar    *label);
+G_CONST_RETURN gchar *gtk_button_get_label          (GtkButton      *button);
+void                  gtk_button_set_use_underline  (GtkButton      *button,
+						     gboolean        use_underline);
+gboolean              gtk_button_get_use_underline  (GtkButton      *button);
+void                  gtk_button_set_use_stock      (GtkButton      *button,
+						     gboolean        use_stock);
+gboolean              gtk_button_get_use_stock      (GtkButton      *button);
+void                  gtk_button_set_focus_on_click (GtkButton      *button,
+						     gboolean        focus_on_click);
+gboolean              gtk_button_get_focus_on_click (GtkButton      *button);
 
-void _gtk_button_set_depressed (GtkButton    *button,
-				gboolean      depressed);
-void _gtk_button_paint         (GtkButton    *button,
-				GdkRectangle *area,
-				GtkStateType  state_type,
-				GtkShadowType shadow_type,
-				const gchar  *main_detail,
-				const gchar  *default_detail);
+
+void _gtk_button_set_depressed             (GtkButton     *button,
+					    gboolean       depressed);
+void _gtk_button_paint                     (GtkButton     *button,
+					    GdkRectangle  *area,
+					    GtkStateType   state_type,
+					    GtkShadowType  shadow_type,
+					    const gchar   *main_detail,
+					    const gchar   *default_detail);
 
 #ifdef __cplusplus
 }
