@@ -43,9 +43,7 @@
 #include "gtkframe.h"
 #include "gtksignal.h"
 #include "gtkmarshalers.h"
-#include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 /* Size of checks and gray levels for alpha compositing checkerboard */
 #define CHECK_SIZE  4
@@ -59,7 +57,7 @@ struct _GtkColorButtonPrivate
   GdkPixbuf *pixbuf;    /* Pixbuf for rendering sample */
   GdkGC *gc;            /* GC for drawing */
   
-  GtkWidget *draw_area; /* Widget where we draw the color sample */
+  GtkWidget *drawing_area;/* Drawing area for color sample */
   GtkWidget *cs_dialog; /* Color selection dialog */
   
   gchar *title;         /* Title for the color selection window */
@@ -103,7 +101,6 @@ static void gtk_color_button_get_property  (GObject        *object,
 
 /* gtkwidget signals */
 static void gtk_color_button_realize       (GtkWidget *widget);
-static void gtk_color_button_unrealize     (GtkWidget *widget);
 static void gtk_color_button_state_changed (GtkWidget           *widget, 
 					    GtkStateType         previous_state);
 static void gtk_color_button_style_set     (GtkWidget *widget, 
@@ -137,7 +134,7 @@ static void gtk_color_button_drag_data_received (GtkWidget        *widget,
 static gpointer parent_class = NULL;
 static guint color_button_signals[LAST_SIGNAL] = { 0 };
 
-static const GtkTargetEntry drop_types[] = { { "application/x-color", 0, 0 } };
+static GtkTargetEntry drop_types[] = { { "application/x-color", 0, 0 } };
 
 GType
 gtk_color_button_get_type (void)
@@ -187,7 +184,6 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
   gobject_class->finalize = gtk_color_button_finalize;
   widget_class->state_changed = gtk_color_button_state_changed;
   widget_class->realize = gtk_color_button_realize;
-  widget_class->unrealize = gtk_color_button_unrealize;
   widget_class->style_set = gtk_color_button_style_set;
   button_class->clicked = gtk_color_button_clicked;
   klass->color_set = NULL;
@@ -203,10 +199,10 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
    */
   g_object_class_install_property (gobject_class,
                                    PROP_USE_ALPHA,
-                                   g_param_spec_boolean ("use-alpha", P_("Use alpha"), 
-                                                         P_("Whether or not to give the color an alpha value"),
+                                   g_param_spec_boolean ("use_alpha", _("Use alpha"), 
+                                                         _("Whether or not to give the color an alpha value"),
                                                          FALSE,
-                                                         GTK_PARAM_READWRITE));
+                                                         (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 
   /**
    * GtkColorButton:title:
@@ -218,10 +214,10 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_TITLE,
                                    g_param_spec_string ("title", 
-							P_("Title"), 
-                                                        P_("The title of the color selection dialog"),
-                                                        _("Pick a Color"),
-                                                        GTK_PARAM_READWRITE));
+							_("Title"), 
+                                                        _("The title of the color selection dialog"),
+                                                        _("Pick a color"),
+                                                        (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 
   /**
    * GtkColorButton:color:
@@ -233,10 +229,10 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_COLOR,
                                    g_param_spec_boxed ("color",
-                                                       P_("Current Color"),
-                                                       P_("The selected color"),
+                                                       _("Current Color"),
+                                                       _("The selected color"),
                                                        GDK_TYPE_COLOR,
-                                                       GTK_PARAM_READWRITE));
+                                                       G_PARAM_READABLE | G_PARAM_WRITABLE));
 
   /**
    * GtkColorButton:alpha:
@@ -248,10 +244,10 @@ gtk_color_button_class_init (GtkColorButtonClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_ALPHA,
                                    g_param_spec_uint ("alpha",
-                                                      P_("Current Alpha"),
-                                                      P_("The selected opacity value (0 fully transparent, 65535 fully opaque)"),
+                                                      _("Current Alpha"),
+                                                      _("The selected opacity value (0 fully transparent, 65535 fully opaque)"),
                                                       0, 65535, 65535,
-                                                      GTK_PARAM_READWRITE));
+                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
         
   /**
    * GtkColorButton::color-set:
@@ -287,8 +283,8 @@ render (GtkColorButton *color_button)
   guint8 insensitive_g = 0;
   guint8 insensitive_b = 0;
 
-  width = color_button->priv->draw_area->allocation.width;
-  height = color_button->priv->draw_area->allocation.height;
+  width = color_button->priv->drawing_area->allocation.width;
+  height = color_button->priv->drawing_area->allocation.height;
   if (color_button->priv->pixbuf == NULL || 
       gdk_pixbuf_get_width (color_button->priv->pixbuf) != width ||
       gdk_pixbuf_get_height (color_button->priv->pixbuf) != height) 
@@ -350,7 +346,7 @@ render (GtkColorButton *color_button)
       
     for (i = 0; i < width; i++) 
       {
-        if (!GTK_WIDGET_IS_SENSITIVE (GTK_WIDGET (color_button)) && (i+j)%2) 
+        if (!GTK_WIDGET_SENSITIVE (GTK_WIDGET (color_button)) && (i+j)%2) 
           {
             *(pixels + j * rowstride + i * 3) = insensitive_r;
             *(pixels + j * rowstride + i * 3 + 1) = insensitive_g;
@@ -380,8 +376,8 @@ expose_event (GtkWidget      *widget,
 {
   GtkColorButton *color_button = GTK_COLOR_BUTTON (data);
 
-  gint width = color_button->priv->draw_area->allocation.width;
-  gint height = color_button->priv->draw_area->allocation.height;
+  gint width = color_button->priv->drawing_area->allocation.width;
+  gint height = color_button->priv->drawing_area->allocation.height;
 
   if (color_button->priv->pixbuf == NULL ||
       width != gdk_pixbuf_get_width (color_button->priv->pixbuf) ||
@@ -391,15 +387,15 @@ expose_event (GtkWidget      *widget,
   gdk_draw_pixbuf (widget->window,
                    color_button->priv->gc,
                    color_button->priv->pixbuf,
-                   event->area.x - widget->allocation.x,
-                   event->area.y - widget->allocation.y,
+                   event->area.x,
+                   event->area.y,
                    event->area.x,
                    event->area.y,
                    event->area.width,
                    event->area.height,
                    GDK_RGB_DITHER_MAX,
-                   event->area.x - widget->allocation.x,
-                   event->area.y - widget->allocation.y);
+                   event->area.x,
+                   event->area.y);
   return FALSE;
 }
 
@@ -410,23 +406,12 @@ gtk_color_button_realize (GtkWidget *widget)
 
   GTK_WIDGET_CLASS (parent_class)->realize (widget);
 
-  color_button->priv->gc = gdk_gc_new (widget->window);
+  if (color_button->priv->gc == NULL)
+    color_button->priv->gc = gdk_gc_new (widget->window);
 
   render (color_button);
 }
 
-
-static void
-gtk_color_button_unrealize (GtkWidget *widget)
-{
-  GtkColorButton *color_button = GTK_COLOR_BUTTON (widget);
-
-  g_object_unref (color_button->priv->gc);
-  color_button->priv->gc = NULL;
-
-  GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
-}
-
 static void
 gtk_color_button_style_set (GtkWidget *widget, 
 			    GtkStyle  *previous_style)
@@ -493,7 +478,7 @@ gtk_color_button_drag_data_received (GtkWidget        *widget,
     g_object_unref (color_button->priv->pixbuf);
   color_button->priv->pixbuf = NULL;
 
-  gtk_widget_queue_draw (color_button->priv->draw_area);
+  gtk_widget_queue_draw (color_button->priv->drawing_area);
 
   g_signal_emit (color_button, color_button_signals[COLOR_SET], 0);
 
@@ -575,20 +560,17 @@ gtk_color_button_init (GtkColorButton *color_button)
   gtk_container_add (GTK_CONTAINER (alignment), frame);
   gtk_widget_show (frame);
 
-  /* Just some widget we can hook to expose-event on */
-  color_button->priv->draw_area = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+  color_button->priv->drawing_area = gtk_drawing_area_new ();
 
   layout = gtk_widget_create_pango_layout (GTK_WIDGET (color_button), "Black");
   pango_layout_get_pixel_extents (layout, NULL, &rect);
-  g_object_unref (layout);
-
-  gtk_widget_set_size_request (color_button->priv->draw_area, rect.width - 2, rect.height - 2);
-  g_signal_connect (color_button->priv->draw_area, "expose-event",
+  gtk_widget_set_size_request (color_button->priv->drawing_area, rect.width - 2, rect.height - 2);
+  g_signal_connect (color_button->priv->drawing_area, "expose_event",
                     G_CALLBACK (expose_event), color_button);
-  gtk_container_add (GTK_CONTAINER (frame), color_button->priv->draw_area);
-  gtk_widget_show (color_button->priv->draw_area);
+  gtk_container_add (GTK_CONTAINER (frame), color_button->priv->drawing_area);
+  gtk_widget_show (color_button->priv->drawing_area);
 
-  color_button->priv->title = g_strdup (_("Pick a Color")); /* default title */
+  color_button->priv->title = g_strdup (_("Pick a color")); /* default title */
 
   /* Create the buffer for the image so that we can create an image.  
    * Also create the picker's pixmap.
@@ -630,7 +612,7 @@ gtk_color_button_finalize (GObject *object)
   GtkColorButton *color_button = GTK_COLOR_BUTTON (object);
 
   if (color_button->priv->gc != NULL)
-    g_object_unref (color_button->priv->gc);
+    g_object_unref (G_OBJECT (color_button->priv->gc));
   color_button->priv->gc = NULL;
 
   if (color_button->priv->cs_dialog != NULL)
@@ -678,7 +660,7 @@ gtk_color_button_new (void)
  * Since: 2.4
  */
 GtkWidget *
-gtk_color_button_new_with_color (const GdkColor *color)
+gtk_color_button_new_with_color (GdkColor *color)
 {
   return g_object_new (GTK_TYPE_COLOR_BUTTON, "color", color, NULL);
 }
@@ -701,7 +683,7 @@ dialog_ok_clicked (GtkWidget *widget,
 
   gtk_widget_hide (color_button->priv->cs_dialog);
 
-  gtk_widget_queue_draw (color_button->priv->draw_area);
+  gtk_widget_queue_draw (color_button->priv->drawing_area);
 
   g_signal_emit (color_button, color_button_signals[COLOR_SET], 0);
 
@@ -794,7 +776,7 @@ gtk_color_button_clicked (GtkButton *button)
  **/
 void
 gtk_color_button_set_color (GtkColorButton *color_button,
-			    const GdkColor *color)
+			    GdkColor       *color)
 {
   g_return_if_fail (GTK_IS_COLOR_BUTTON (color_button));
 
@@ -802,12 +784,6 @@ gtk_color_button_set_color (GtkColorButton *color_button,
   color_button->priv->color.green = color->green;
   color_button->priv->color.blue = color->blue;
 
-  if (color_button->priv->pixbuf != NULL)
-    g_object_unref (color_button->priv->pixbuf);
-  color_button->priv->pixbuf = NULL;
-
-  gtk_widget_queue_draw (color_button->priv->draw_area);
-  
   g_object_notify (G_OBJECT (color_button), "color");
 }
 
@@ -828,13 +804,7 @@ gtk_color_button_set_alpha (GtkColorButton *color_button,
   g_return_if_fail (GTK_IS_COLOR_BUTTON (color_button));
 
   color_button->priv->alpha = alpha;
-
-  if (color_button->priv->pixbuf != NULL)
-    g_object_unref (color_button->priv->pixbuf);
-  color_button->priv->pixbuf = NULL;
-
-  gtk_widget_queue_draw (color_button->priv->draw_area);
-
+  
   g_object_notify (G_OBJECT (color_button), "alpha");
 }
 
@@ -898,9 +868,9 @@ gtk_color_button_set_use_alpha (GtkColorButton *color_button,
       color_button->priv->use_alpha = use_alpha;
 
       render (color_button);
-      gtk_widget_queue_draw (color_button->priv->draw_area);
+      gtk_widget_queue_draw (color_button->priv->drawing_area);
 
-      g_object_notify (G_OBJECT (color_button), "use-alpha");
+      g_object_notify (G_OBJECT (color_button), "use_alpha");
     }
 }
 
@@ -1026,6 +996,3 @@ gtk_color_button_get_property (GObject    *object,
       break;
     }
 }
-
-#define __GTK_COLOR_BUTTON_C__
-#include "gtkaliasdef.c"
