@@ -47,12 +47,15 @@
 #include "gtkmenu.h"
 #include "gtkmenuitem.h"
 #include "gtknotebook.h"
-#include "gtkoptionmenu.h"
 #include "gtkscrolledwindow.h"
 #include "gtkstock.h"
 #include "gtktable.h"
 #include "gtkvbox.h"
 
+#undef GTK_DISABLE_DEPRECATED
+#include "gtkoptionmenu.h"
+#define GTK_DISABLE_DEPRECATED
+
 #include "gtkintl.h"
 
 typedef struct _GtkInputDialogPrivate GtkInputDialogPrivate;
@@ -648,7 +651,7 @@ gtk_input_dialog_set_key (GtkInputKeyInfo *key,
 
   if (keyval)
     {
-      str = g_string_new("");
+      str = g_string_new (NULL);
       
       if (modifiers & GDK_SHIFT_MASK)
 	g_string_append (str, "Shift+");
