@@ -76,7 +76,8 @@ typedef enum
    */
   GTK_RECEIVES_DEFAULT = 1 << 20,
 
-  GTK_DOUBLE_BUFFERED  = 1 << 21
+  GTK_DOUBLE_BUFFERED  = 1 << 21,
+  GTK_NO_SHOW_ALL      = 1 << 22
 } GtkWidgetFlags;
 
 /* Kinds of widget-specific help */
@@ -90,11 +91,11 @@ typedef enum
  * Macros for testing whether `widget' or `klass' are of type GTK_TYPE_WIDGET.
  */
 #define GTK_TYPE_WIDGET			  (gtk_widget_get_type ())
-#define GTK_WIDGET(widget)		  (GTK_CHECK_CAST ((widget), GTK_TYPE_WIDGET, GtkWidget))
-#define GTK_WIDGET_CLASS(klass)		  (GTK_CHECK_CLASS_CAST ((klass), GTK_TYPE_WIDGET, GtkWidgetClass))
-#define GTK_IS_WIDGET(widget)		  (GTK_CHECK_TYPE ((widget), GTK_TYPE_WIDGET))
-#define GTK_IS_WIDGET_CLASS(klass)	  (GTK_CHECK_CLASS_TYPE ((klass), GTK_TYPE_WIDGET))
-#define GTK_WIDGET_GET_CLASS(obj)         (GTK_CHECK_GET_CLASS ((obj), GTK_TYPE_WIDGET, GtkWidgetClass))
+#define GTK_WIDGET(widget)		  (G_TYPE_CHECK_INSTANCE_CAST ((widget), GTK_TYPE_WIDGET, GtkWidget))
+#define GTK_WIDGET_CLASS(klass)		  (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_WIDGET, GtkWidgetClass))
+#define GTK_IS_WIDGET(widget)		  (G_TYPE_CHECK_INSTANCE_TYPE ((widget), GTK_TYPE_WIDGET))
+#define GTK_IS_WIDGET_CLASS(klass)	  (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_WIDGET))
+#define GTK_WIDGET_GET_CLASS(obj)         (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_WIDGET, GtkWidgetClass))
 
 /* Macros for extracting various fields from GtkWidget and GtkWidgetClass.
  */
@@ -197,6 +198,8 @@ struct _GtkWidget
    */
   gchar *name;
   
+  /*< public >*/
+
   /* The style for the widget. The style contains the
    *  colors the widget should be drawn in for each state
    *  along with graphics contexts used to draw with and
@@ -343,10 +346,10 @@ struct _GtkWidgetClass
   void (* selection_get)           (GtkWidget          *widget,
 				    GtkSelectionData   *selection_data,
 				    guint               info,
-				    guint               time);
+				    guint               time_);
   void (* selection_received)      (GtkWidget          *widget,
 				    GtkSelectionData   *selection_data,
-				    guint               time);
+				    guint               time_);
 
   /* Source side drag signals */
   void (* drag_begin)	           (GtkWidget	       *widget,
@@ -357,31 +360,31 @@ struct _GtkWidgetClass
 				    GdkDragContext     *context,
 				    GtkSelectionData   *selection_data,
 				    guint               info,
-				    guint               time);
+				    guint               time_);
   void (* drag_data_delete)        (GtkWidget	       *widget,
 				    GdkDragContext     *context);
 
   /* Target side drag signals */
   void (* drag_leave)	           (GtkWidget	       *widget,
 				    GdkDragContext     *context,
-				    guint               time);
+				    guint               time_);
   gboolean (* drag_motion)         (GtkWidget	       *widget,
 				    GdkDragContext     *context,
 				    gint                x,
 				    gint                y,
-				    guint               time);
+				    guint               time_);
   gboolean (* drag_drop)           (GtkWidget	       *widget,
 				    GdkDragContext     *context,
 				    gint                x,
 				    gint                y,
-				    guint               time);
+				    guint               time_);
   void (* drag_data_received)      (GtkWidget          *widget,
 				    GdkDragContext     *context,
 				    gint                x,
 				    gint                y,
 				    GtkSelectionData   *selection_data,
 				    guint               info,
-				    guint               time);
+				    guint               time_);
 
   /* Signals used only for keybindings */
   gboolean (* popup_menu)          (GtkWidget          *widget);
@@ -398,6 +401,8 @@ struct _GtkWidgetClass
    */
   AtkObject*   (* get_accessible)  (GtkWidget          *widget);
 
+  void (* screen_changed) (GtkWidget *widget,
+			   GdkScreen *previous_screen);
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
   void (*_gtk_reserved2) (void);
@@ -406,7 +411,6 @@ struct _GtkWidgetClass
   void (*_gtk_reserved5) (void);
   void (*_gtk_reserved6) (void);
   void (*_gtk_reserved7) (void);
-  void (*_gtk_reserved8) (void);
 };
 
 struct _GtkWidgetAuxInfo
@@ -426,8 +430,8 @@ struct _GtkWidgetShapeInfo
   GdkBitmap *shape_mask;
 };
 
-GtkType	   gtk_widget_get_type		  (void) G_GNUC_CONST;
-GtkWidget* gtk_widget_new		  (GtkType		type,
+GType	   gtk_widget_get_type		  (void) G_GNUC_CONST;
+GtkWidget* gtk_widget_new		  (GType		type,
 					   const gchar	       *first_property_name,
 					   ...);
 GtkWidget* gtk_widget_ref		  (GtkWidget	       *widget);
@@ -446,6 +450,9 @@ void       gtk_widget_show_now            (GtkWidget           *widget);
 void	   gtk_widget_hide		  (GtkWidget	       *widget);
 void	   gtk_widget_show_all		  (GtkWidget	       *widget);
 void	   gtk_widget_hide_all		  (GtkWidget	       *widget);
+void       gtk_widget_set_no_show_all     (GtkWidget           *widget,
+					   gboolean             no_show_all);
+gboolean   gtk_widget_get_no_show_all     (GtkWidget           *widget);
 void	   gtk_widget_map		  (GtkWidget	       *widget);
 void	   gtk_widget_unmap		  (GtkWidget	       *widget);
 void	   gtk_widget_realize		  (GtkWidget	       *widget);
@@ -469,6 +476,7 @@ void	   gtk_widget_queue_clear_area	  (GtkWidget	       *widget,
 
 
 void	   gtk_widget_queue_resize	  (GtkWidget	       *widget);
+void	   gtk_widget_queue_resize_no_redraw (GtkWidget *widget);
 #ifndef GTK_DISABLE_DEPRECATED
 void	   gtk_widget_draw		  (GtkWidget	       *widget,
 					   GdkRectangle	       *area);
@@ -576,7 +584,7 @@ void	   gtk_widget_set_extension_events (GtkWidget		*widget,
 GdkExtensionMode gtk_widget_get_extension_events (GtkWidget	*widget);
 GtkWidget*   gtk_widget_get_toplevel	(GtkWidget	*widget);
 GtkWidget*   gtk_widget_get_ancestor	(GtkWidget	*widget,
-					 GtkType	widget_type);
+					 GType		 widget_type);
 GdkColormap* gtk_widget_get_colormap	(GtkWidget	*widget);
 GdkVisual*   gtk_widget_get_visual	(GtkWidget	*widget);
 
@@ -761,6 +769,8 @@ GtkWidgetAuxInfo *_gtk_widget_get_aux_info                (GtkWidget    *widget,
 							   gboolean      create);
 void              _gtk_widget_propagate_hierarchy_changed (GtkWidget    *widget,
 							   GtkWidget    *previous_toplevel);
+void              _gtk_widget_propagate_screen_changed    (GtkWidget    *widget,
+							   GdkScreen    *previous_screen);
 
 GdkColormap* _gtk_widget_peek_colormap (void);
 
